@@ -11,10 +11,13 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
+
 import logging
-from muranodashboard.environments import api
-from muranodashboard.environments import consts
+
+from muranodashboard import api
 from muranodashboard.common import utils
+from muranodashboard.environments import api as env_api
+from muranodashboard.environments import consts
 
 LOG = logging.getLogger(__name__)
 
@@ -34,25 +37,26 @@ class BillingStats(object):
         return st_list
 
     def get_all(self, request):
-        env_list = api.environments_list(request)
+        env_list = env_api.environments_list(request)
         stats = []
         LOG.debug('Got env list: {0}'.format(env_list))
         for env in env_list:
             env_entry = utils.Bunch(name=env.name,
                                     id=env.id)
             services = self.build_service_list(request, env)
-            LOG.debug('Processing env: {0}'.format(env))
-            env_stats = self.get_stats_for_env(request, env.id)
-            stats_list = []
-            for entry in env_stats:
-                instance_id = entry.instance_id
-                service = services[instance_id]
-                stat_entry = utils.Bunch(**entry.to_dict())
-                stat_entry.service = service['name']
-                stat_entry.service_type = service['type']
-                stats_list.append(stat_entry)
-            env_entry.instances = stats_list
-            stats.append(env_entry)
+            if services:
+                LOG.debug('Processing env: {0}'.format(env))
+                env_stats = self.get_stats_for_env(request, env.id)
+                stats_list = []
+                for entry in env_stats:
+                    instance_id = entry.instance_id
+                    service = services[instance_id]
+                    stat_entry = utils.Bunch(**entry.to_dict())
+                    stat_entry.service = service['name']
+                    stat_entry.service_type = service['type']
+                    stats_list.append(stat_entry)
+                env_entry.instances = stats_list
+                stats.append(env_entry)
 
         LOG.debug('Created statistics: {0}'.format(stats))
         return stats
@@ -73,20 +77,23 @@ class BillingStats(object):
                 for _node in node:
                     _rec(_node)
 
-        for item in service:
-            _rec(item)
+        for attr in dir(service):
+            if not attr.startswith('_'):
+                _rec(getattr(service, attr))
         return ids
 
     def build_service_list(self, request, env):
-        serv_list = api.services_list(request, env.id)
+        serv_list = api.muranoclient(request).services.list(env.id)
         LOG.debug('Got Service List: {0}'.format(serv_list))
-        id_list = {}
+        ids = {}
         for service in serv_list:
-            ids = self._get_instances_ids(service)
-            storage = service['?'][consts.DASHBOARD_ATTRS_KEY]
-            info = {'name': storage['name'], 'type': service['?']['type']}
-            id_list.update(dict((_id, info) for _id in ids))
-        return id_list
+            id_list = self._get_instances_ids(service)
+            service_meta_info = getattr(service, '?')
+            storage = service_meta_info[consts.DASHBOARD_ATTRS_KEY]
+            info = {'name': storage['name'],
+                    'type': service_meta_info['type']}
+            ids.update(dict((_id, info) for _id in id_list))
+        return ids
 
 
 class Stats(object):
